@@ -13,7 +13,7 @@
  *
  * Author:	Miquel van Smoorenburg, miquels@cistron.nl
  *
- * Version:	@(#)shutdown  2.76  19-Apr-1999  miquels@cistron.nl
+ * Version:	@(#)shutdown  2.78  13-Nov-1999  miquels@cistron.nl
  *
  *		This file is part of the sysvinit suite,
  *		Copyright 1991-1999 Miquel van Smoorenburg.
@@ -37,7 +37,7 @@
 #include "paths.h"
 #include "reboot.h"
 
-char *Version = "@(#) shutdown 2.76 19-Apr-1999 miquels@cistron.nl";
+char *Version = "@(#) shutdown 2.78 13-Nov-1999 miquels@cistron.nl";
 
 #define MESSAGELEN	256
 
@@ -129,13 +129,13 @@ int mins;
 /*
  * Create the /etc/nologin file.
  */
-void donologin()
+void donologin(int min)
 {
   FILE *fp;
   time_t t;
 
   time(&t);
-  t += 300;
+  t += 60 * min;
 
   unlink(NOLOGIN);
   if ((fp = fopen(NOLOGIN, "w")) != NULL) {
@@ -212,6 +212,7 @@ void fastdown()
   system("accton 2>/dev/null");
   system("quotaoff -a 2>/dev/null");
 
+  sync();
   fprintf(stderr, "shutdown: turning off swap\r\n");
   system("swapoff -a");
   fprintf(stderr, "shutdown: unmounting all file systems\r\n");
@@ -259,6 +260,7 @@ void shutdown()
   unlink(NOLOGIN);
 
   /* Now execute init to change runlevel. */
+  sync();
   execv(INIT, args);
 
   /* Oops - failed. */
@@ -521,7 +523,7 @@ char **argv;
   if (wt < 15 && wt!= 10 && wt != 5 && wt != 1) warn(wt);
   while(wt) {
 	if (wt <= 5 && !didnolog) {
-		donologin();
+		donologin(wt);
 		didnolog++;
 	}
 	if (wt == 15 || wt == 10 || wt == 5 || wt == 1) warn(wt);
